octavia-lib Style Commandments
==============================

- Read the OpenStack Style Commandments:
  https://docs.openstack.org/hacking/latest/

- Read the OpenStack Octavia style guide:
  https://docs.openstack.org/octavia/latest/contributor/HACKING.html
